{
    "$graph": [
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "bcftools",
                "concat"
            ],
            "requirements": [
                {
                    "dockerPull": "mercury/bcftools-1.6:v2",
                    "class": "DockerRequirement"
                }
            ],
            "arguments": [
                {
                    "prefix": "-o",
                    "valueFrom": "final.vcf"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "array of vcf files to be concatenated (which should all come from the same original vcf )\n",
                    "id": "#ROH_combine.cwl/files"
                }
            ],
            "doc": "Concatenate vcfs\n",
            "id": "#ROH_combine.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "final*.vcf"
                    },
                    "id": "#ROH_combine.cwl/output1"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "bash"
            ],
            "requirements": [
                {
                    "dockerPull": "mercury/bcftools-1.6:v2",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "input files of known ROH for each chromosome (truth set) \\\nformat RG\t[2]Sample\t[3]Chromosome\t[4]Start\t[5]End\t[6]Length (bp)\t[7]Number of markers\t[8]Quality (average fwd-bwd phred score)\n",
                    "id": "#ROH_comparison.cwl/filein_ROH"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "input vcf, from variant caller being tested\n",
                    "id": "#ROH_comparison.cwl/filein_VCF"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "doc": "map sample names between vcf and ROH truth set\n",
                    "id": "#ROH_comparison.cwl/sample_mapping"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Script to calculate het calls in known region of homozygosity (ROH), \nfor comparison of variant callers\n",
                    "id": "#ROH_comparison.cwl/script"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output*.vcf"
                    },
                    "id": "#ROH_comparison.cwl/output1"
                }
            ],
            "doc": "Run script to calculate het calls in known region of homozygosity (ROH)\n",
            "id": "#ROH_comparison.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/script",
                    "type": "File"
                },
                {
                    "id": "#main/ROH_chr",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#main/vcf_file",
                    "type": "File"
                },
                {
                    "id": "#main/sample_mapping",
                    "type": "File"
                }
            ],
            "steps": [
                {
                    "id": "#main/ROH_calc",
                    "scatter": [
                        "#main/ROH_calc/filein_ROH"
                    ],
                    "run": "#ROH_comparison.cwl",
                    "in": [
                        {
                            "source": "#main/ROH_chr",
                            "id": "#main/ROH_calc/filein_ROH"
                        },
                        {
                            "source": "#main/vcf_file",
                            "id": "#main/ROH_calc/filein_VCF"
                        },
                        {
                            "source": "#main/sample_mapping",
                            "id": "#main/ROH_calc/sample_mapping"
                        },
                        {
                            "source": "#main/script",
                            "id": "#main/ROH_calc/script"
                        }
                    ],
                    "out": [
                        "#main/ROH_calc/output1"
                    ]
                },
                {
                    "id": "#main/ROH_combine",
                    "run": "#ROH_combine.cwl",
                    "in": [
                        {
                            "source": "#main/ROH_calc/output1",
                            "id": "#main/ROH_combine/files"
                        }
                    ],
                    "out": [
                        "#main/ROH_combine/output1"
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#main/stats",
                    "type": "File",
                    "outputSource": [
                        "#main/ROH_combine/output1"
                    ]
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "arv": "http://arvados.org/cwl#",
        "cwltool": "http://commonwl.org/cwltool#"
    }
}
